@@ -1,6 +1,6 @@
 use crate::{
     buffers::{BufferDescription, BufferKind},
-    execute::{columns, execute_with_parameters},
+    execute::{execute_columns, execute_tables, execute_with_parameters},
     handles::{self, State, Statement, StatementImpl},
     parameter_collection::ParameterCollection,
     CursorImpl, Error, Preallocated, Prepared,
@@ -64,7 +64,7 @@ impl<'c> Connection<'c> {
         &self,
         query: &U16Str,
         params: impl ParameterCollection,
-    ) -> Result<Option<CursorImpl<'_, StatementImpl<'_>>>, Error> {
+    ) -> Result<Option<CursorImpl<StatementImpl<'_>>>, Error> {
         let lazy_statement = move || self.allocate_statement();
         execute_with_parameters(lazy_statement, Some(query), params)
     }
@@ -102,7 +102,7 @@ impl<'c> Connection<'c> {
         &self,
         query: &str,
         params: impl ParameterCollection,
-    ) -> Result<Option<CursorImpl<'_, StatementImpl<'_>>>, Error> {
+    ) -> Result<Option<CursorImpl<StatementImpl<'_>>>, Error> {
         let query = U16String::from_str(query);
         self.execute_utf16(&query, params)
     }
@@ -322,8 +322,8 @@ impl<'c> Connection<'c> {
         schema_name: &str,
         table_name: &str,
         column_name: &str,
-    ) -> Result<CursorImpl<'_, StatementImpl<'_>>, Error> {
-        columns(
+    ) -> Result<CursorImpl<StatementImpl<'_>>, Error> {
+        execute_columns(
             self.allocate_statement()?,
             &U16String::from_str(catalog_name),
             &U16String::from_str(schema_name),
@@ -332,6 +332,85 @@ impl<'c> Connection<'c> {
         )
     }
 
+    /// List tables, schemas, views and catalogs of a datasource.
+    ///
+    /// # Parameters
+    ///
+    /// * `catalog_name`: Filter result by catalog name. Accept search patterns. Use `%` to match
+    ///   any number of characters. Use `_` to match exactly on character. Use `\` to escape
+    ///   characeters.
+    /// * `schema_name`: Filter result by schema. Accepts patterns in the same way as
+    ///   `catalog_name`.
+    /// * `table_name`: Filter result by table. Accepts patterns in the same way as `catalog_name`.
+    /// * `table_type`: Filters results by table type. E.g: 'TABLE', 'VIEW'. This argument accepts a
+    ///   comma separeted list of table types. Omit it to not filter the result by table type at
+    ///   all.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// use odbc_api::{Connection, Cursor, Error, buffers::TextRowSet};
+    ///
+    /// fn print_all_tables(conn: &Connection<'_>) -> Result<(), Error> {
+    ///     // Set all filters to None, to really print all tables
+    ///     let cursor = conn.tables(None, None, None, None)?;
+    ///
+    ///     // The column are gonna be TABLE_CAT,TABLE_SCHEM,TABLE_NAME,TABLE_TYPE,REMARKS, but may
+    ///     // also contain additional driver specific columns.
+    ///     for (index, name) in cursor.column_names()?.enumerate() {
+    ///         if index != 0 {
+    ///             print!(",")
+    ///         }
+    ///         print!("{}", name?);
+    ///     }
+    ///
+    ///     let batch_size = 100;
+    ///     let mut buffer = TextRowSet::for_cursor(batch_size, &cursor, Some(4096))?;
+    ///     let mut row_set_cursor = cursor.bind_buffer(&mut buffer)?;
+    ///
+    ///     while let Some(row_set) = row_set_cursor.fetch()? {
+    ///         for row_index in 0..row_set.num_rows() {
+    ///             if row_index != 0 {
+    ///                 print!("\n");
+    ///             }
+    ///             for col_index in 0..row_set.num_cols() {
+    ///                 if col_index != 0 {
+    ///                     print!(",");
+    ///                 }
+    ///                 let value = row_set
+    ///                     .at_as_str(col_index, row_index)
+    ///                     .unwrap()
+    ///                     .unwrap_or("NULL");
+    ///                 print!("{}", value);
+    ///             }
+    ///         }
+    ///     }
+    ///
+    ///     Ok(())
+    /// }
+    /// ```
+    pub fn tables(
+        &self,
+        catalog_name: Option<&str>,
+        schema_name: Option<&str>,
+        table_name: Option<&str>,
+        table_type: Option<&str>,
+    ) -> Result<CursorImpl<StatementImpl<'_>>, Error> {
+        let statement = self.allocate_statement()?;
+
+        let catalog_name = catalog_name.map(|s| U16String::from_str(s));
+        let schema_name = schema_name.map(|s| U16String::from_str(s));
+        let table_name = table_name.map(|s| U16String::from_str(s));
+        let table_type = table_type.map(|s| U16String::from_str(s));
+        execute_tables(
+            statement,
+            catalog_name.as_deref(),
+            schema_name.as_deref(),
+            table_name.as_deref(),
+            table_type.as_deref(),
+        )
+    }
+
     /// The buffer descriptions for all standard buffers (not including extensions) returned in the
     /// columns query (e.g. [`Connection::columns`]).
     ///
