@@ -12,10 +12,16 @@ use odbc_sys::{
     Desc, FreeStmtOption, HDbc, HStmt, Handle, HandleType, Len, ParamType, Pointer, SQLBindCol,
     SQLBindParameter, SQLCloseCursor, SQLColAttributeW, SQLColumnsW, SQLDescribeColW,
     SQLDescribeParam, SQLExecDirectW, SQLExecute, SQLFetch, SQLFreeStmt, SQLGetData,
-    SQLNumResultCols, SQLParamData, SQLPrepareW, SQLPutData, SQLSetStmtAttrW, SqlDataType,
-    SqlReturn, StatementAttribute, ULen,
+    SQLNumResultCols, SQLParamData, SQLPrepareW, SQLPutData, SQLSetStmtAttrW, SQLTablesW,
+    SqlDataType, SqlReturn, StatementAttribute, ULen,
+};
+use std::{
+    convert::TryInto,
+    ffi::c_void,
+    marker::PhantomData,
+    mem::ManuallyDrop,
+    ptr::{null, null_mut},
 };
-use std::{convert::TryInto, ffi::c_void, marker::PhantomData, mem::ManuallyDrop, ptr::null_mut};
 use widestring::U16Str;
 
 /// Wraps a valid (i.e. successfully allocated) ODBC statement handle.
@@ -343,6 +349,18 @@ pub trait Statement: AsHandle {
         .into_sql_result("SQLSetStmtAttrW")
     }
 
+    fn set_metadata_id(&mut self, metadata_id: bool) -> SqlResult<()> {
+        unsafe {
+            SQLSetStmtAttrW(
+                self.as_sys(),
+                StatementAttribute::MetadataId,
+                metadata_id as u8 as Pointer,
+                0,
+            )
+            .into_sql_result("SQLSetStmtAttrW")
+        }
+    }
+
     /// Binds a buffer holding an input parameter to a parameter marker in an SQL statement. This
     /// specialized version takes a constant reference to parameter, but is therefore limited to
     /// binding input parameters. See [`Statement::bind_parameter`] for the version which can bind
@@ -636,6 +654,49 @@ pub trait Statement: AsHandle {
         }
     }
 
+    /// Returns the list of table, catalog, or schema names, and table types, stored in a specific
+    /// data source. The driver returns the information as a result set.
+    /// 
+    /// The catalog, schema and table parameters are search patterns by default unless
+    /// [`Self::set_metadata_id`] is called with `true`. In that case they must also not be `None` since
+    /// otherwise a NulPointer error is emitted.
+    fn tables(
+        &mut self,
+        catalog_name: Option<&U16Str>,
+        schema_name: Option<&U16Str>,
+        table_name: Option<&U16Str>,
+        table_type: Option<&U16Str>,
+    ) -> SqlResult<()> {
+        // Convert each filter into a pair of buffer pointer and buffer length.
+        let to_buf = |filter: Option<&U16Str>| {
+            if let Some(text) = filter {
+                (buf_ptr(text.as_slice()), text.len().try_into().unwrap())
+            } else {
+                (null(), 0i16)
+            }
+        };
+
+        let catalog = to_buf(catalog_name);
+        let schema = to_buf(schema_name);
+        let table = to_buf(table_name);
+        let type_ = to_buf(table_type);
+
+        unsafe {
+            SQLTablesW(
+                self.as_sys(),
+                catalog.0,
+                catalog.1,
+                schema.0,
+                schema.1,
+                table.0,
+                table.1,
+                type_.0,
+                type_.1,
+            )
+            .into_sql_result("SQLTablesW")
+        }
+    }
+
     /// To put a batch of binary data into the data source at statement execution time. Returns true
     /// if the `NEED_DATA` is returned by the driver.
     ///
