@@ -1,7 +1,4 @@
-use crate::{
-    handles::{Statement, StatementImpl},
-    Error, InputParameter, Parameter,
-};
+use crate::{handles::Statement, Error, InputParameter, Parameter};
 
 mod tuple;
 
@@ -74,7 +71,7 @@ pub unsafe trait ParameterCollection {
     /// Implementers should take care that the values bound by this method to the statement live at
     /// least for the Duration of `self`. The most straight forward way of achieving this is of
     /// course, to bind members.
-    unsafe fn bind_parameters_to(self, stmt: &mut StatementImpl<'_>) -> Result<(), Error>;
+    unsafe fn bind_parameters_to(self, stmt: &mut impl Statement) -> Result<(), Error>;
 }
 
 unsafe impl<T> ParameterCollection for T
@@ -85,7 +82,7 @@ where
         1
     }
 
-    unsafe fn bind_parameters_to(self, stmt: &mut StatementImpl<'_>) -> Result<(), Error> {
+    unsafe fn bind_parameters_to(self, stmt: &mut impl Statement) -> Result<(), Error> {
         self.bind_parameter(1, stmt)
     }
 }
@@ -98,7 +95,7 @@ where
         1
     }
 
-    unsafe fn bind_parameters_to(self, stmt: &mut StatementImpl<'_>) -> Result<(), Error> {
+    unsafe fn bind_parameters_to(self, stmt: &mut impl Statement) -> Result<(), Error> {
         for (index, parameter) in self.iter().enumerate() {
             stmt.bind_input_parameter(index as u16 + 1, parameter)
                 .into_result(stmt)?;
