@@ -2635,6 +2635,22 @@ fn no_data(profile: &Profile) {
     conn.prepare(&sql).unwrap().execute(()).unwrap();
 }
 
+/// List tables for various data sources
+#[test_case(MSSQL, "master,dbo,ListTables,TABLE,NULL"; "Microsoft SQL Server")]
+#[test_case(MARIADB, "test_db,NULL,ListTables,TABLE,"; "Maria DB")]
+#[test_case(SQLITE_3, "NULL,NULL,ListTables,TABLE,NULL"; "SQLite 3")]
+fn list_tables(profile: &Profile, expected: &str) {
+    let table_name = "ListTables";
+    let conn = profile.connection().unwrap();
+
+    setup_empty_table(&conn, profile.index_type, table_name, &["INTEGER"]).unwrap();
+
+    let cursor = conn.tables(None, None, Some(table_name), None).unwrap();
+    let actual = cursor_to_string(cursor);
+
+    assert_eq!(expected, actual);
+}
+
 /// Some drivers seem to have trouble binding buffers beyond `u16::MAX`. This has been seen failing
 /// in the wild with SAP anywhere, but that ODBC driver is not part of this test suite.
 #[test_case(MSSQL; "Microsoft SQL Server")]
